@@ -2,8 +2,9 @@
   Copyright (c) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,11 +35,10 @@ class KPIM::TagWidgetPrivate
 {
 public:
     TagWidgetPrivate()
-        : mTagWidget(nullptr)
     {
     }
 
-    Akonadi::TagWidget *mTagWidget;
+    Akonadi::TagWidget *mTagWidget = nullptr;
     Akonadi::Tag::List mTagList;
     QStringList mCachedTagNames;
 };
@@ -49,11 +49,10 @@ TagWidget::TagWidget(QWidget *parent)
 {
     d->mTagWidget = new Akonadi::TagWidget(this);
     connect(d->mTagWidget, &Akonadi::TagWidget::selectionChanged, this, &TagWidget::onSelectionChanged);
-    QHBoxLayout *l = new QHBoxLayout;
+    QHBoxLayout *l = new QHBoxLayout(this);
     l->setMargin(0);
     l->setSpacing(0);
     l->addWidget(d->mTagWidget);
-    setLayout(l);
 }
 
 TagWidget::~TagWidget()
